==> knative-model-6.5.0-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelListFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface InMemoryChannelListFluent<A extends InMemoryChannelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,InMemoryChannel item);
  public A setToItems(Integer index,InMemoryChannel item);
  public A addToItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public A addAllToItems(Collection<InMemoryChannel> items);
  public A removeFromItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public A removeAllFromItems(Collection<InMemoryChannel> items);
  public A removeMatchingFromItems(Predicate<InMemoryChannelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<InMemoryChannel> getItems();
  public List<InMemoryChannel> buildItems();
  public InMemoryChannel buildItem(Integer index);
  public InMemoryChannel buildFirstItem();
  public InMemoryChannel buildLastItem();
  public InMemoryChannel buildMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public A withItems(List<InMemoryChannel> items);
  public A withItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public Boolean hasItems();
  public InMemoryChannelListFluent.ItemsNested<A> addNewItem();
  public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item);
  public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(Integer index,InMemoryChannel item);
  public InMemoryChannelListFluent.ItemsNested<A> editItem(Integer index);
  public InMemoryChannelListFluent.ItemsNested<A> editFirstItem();
  public InMemoryChannelListFluent.ItemsNested<A> editLastItem();
  public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,InMemoryChannelFluent<InMemoryChannelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelListFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface InMemoryChannelListFluent<A extends InMemoryChannelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,InMemoryChannel item);
  public A setToItems(int index,InMemoryChannel item);
  public A addToItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public A addAllToItems(Collection<InMemoryChannel> items);
  public A removeFromItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public A removeAllFromItems(Collection<InMemoryChannel> items);
  public A removeMatchingFromItems(Predicate<InMemoryChannelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<InMemoryChannel> getItems();
  public List<InMemoryChannel> buildItems();
  public InMemoryChannel buildItem(int index);
  public InMemoryChannel buildFirstItem();
  public InMemoryChannel buildLastItem();
  public InMemoryChannel buildMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public A withItems(List<InMemoryChannel> items);
  public A withItems(io.fabric8.knative.messaging.v1.InMemoryChannel... items);
  public Boolean hasItems();
  public InMemoryChannelListFluent.ItemsNested<A> addNewItem();
  public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item);
  public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(int index,InMemoryChannel item);
  public InMemoryChannelListFluent.ItemsNested<A> editItem(int index);
  public InMemoryChannelListFluent.ItemsNested<A> editFirstItem();
  public InMemoryChannelListFluent.ItemsNested<A> editLastItem();
  public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(Predicate<InMemoryChannelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,InMemoryChannelFluent<InMemoryChannelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
